# BaseIdtableIdOrNamePerformUpsert

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**fields_to_merge_on** | **list[str]** | An array with at least one and at most three field names or IDs. IDs must uniquely identify a single record. These cannot be computed fields (formulas, lookups, rollups), and must be one of the following types - number, text, long text, single select, multiple select, date. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

